@@ -1,13 +1,13 @@
-#if HAVE_DEMANGLE
-
 #include <string.h>
+#include <stdlib.h>
+#if HAVE_DEMANGLE
 #include <demangle.h>
 
 const char* ezt_demangle(const char* mangled_str) {
   /* todo: add an option to get only the function name */
   /* get the full function prototype (including parameters and return type)  */
 
-  const char* res_str = cplus_demangle(mangled_str, DMGL_AUTO | DMGL_PARAMS);
+  char* res_str = cplus_demangle(mangled_str, DMGL_AUTO | DMGL_PARAMS);
 
   if(!res_str) {
     /* demangling failed. return the mangled string */
@@ -23,7 +23,7 @@ const char* ezt_demangle(const char* mangled_str) {
 /* Libiberty is not available, return a copy of the mangled string */
 const char* ezt_demangle(const char* mangled_str) {
   int len = strlen(mangled_str) + 1;
-  const char* res_str = malloc(sizeof(char*) * len);
+  char* res_str = malloc(sizeof(char*) * len);
   strncpy(res_str, mangled_str, len);
   return res_str;
 }
