@@ -19,7 +19,7 @@
 #include <stddef.h>
 #include <stdint.h>
 #include <dlfcn.h>
-#ifdef USE_GETTID
+#if USE_GETTID
 #include <unistd.h>
 #include <sys/syscall.h>	/* For SYS_xxx definitions */
 #else
@@ -136,7 +136,7 @@ extern struct __ezt_write_trace __ezt_trace;
   }
 
 /* current thread id */
-#ifdef USE_GETTID
+#if USE_GETTID
 #define CUR_TID syscall(SYS_gettid)
 #else
 #define CUR_TID pthread_self()
@@ -171,7 +171,6 @@ extern struct __ezt_write_trace __ezt_trace;
     if(var) break;						\
     void *__handle = RTLD_NEXT;					\
     var = (typeof(var)) (uintptr_t) dlsym(__handle, func);	\
-    TREAT_ERROR();						\
   } while(0)
 
 /* return the offset of the field MEMBER in a structure TYPE */
@@ -211,7 +210,7 @@ void set_recursion_shield_off();
 #define PPTRACE_INTERCEPT_FULL(function, repl, orig) #function " " #orig " " #repl,
 #define PPTRACE_INTERCEPT(function) #function " orig_" #function " " #function,
 
-#define PPTRACE_START_INTERCEPT(module_name) char* PPTRACE_SYMBOL_LIST(module_name) [] __attribute__((visibility("protected"))) = {
+#define PPTRACE_START_INTERCEPT(module_name) char* PPTRACE_SYMBOL_LIST(module_name) [] = {
 #define PPTRACE_END_INTERCEPT(module_name)  NULL }; extern char** PPTRACE_SYMBOL_EXTERNAL(module_name) __attribute__((alias(PPTRACE_SYMBOL_ALIAS(module_name))));
 
 #define ezt_is_in_launcher() ((getenv("TESTLAUNCHER") != NULL) && (strcmp(getenv("TESTLAUNCHER"), "1") == 0))
@@ -225,7 +224,6 @@ void set_recursion_shield_off();
     }							\
     if(NULL != *var) break;				\
     *var = (void*) dlsym((void*)-1l, func);		\
-    TREAT_ERROR();					\
   } while(0)
 
 #define DYNAMIC_INTERCEPT_ALL_MODULE(module_name)		\
@@ -254,4 +252,16 @@ void set_recursion_shield_off();
 
 #define INTERCEPT2(func, var) func " " #var " " func,
 
+
+
+/* record events (code=EZTRACE_CALLING_FUNCTION) containing the backtrace */
+void eztrace_record_backtrace(int backtrace_depth);
+void record_backtrace();
+
+/* get information on frame frameid
+ * the collected information is copied into output_str
+ * buffer_len is the maximum number of bytes written to output_str
+ */
+void eztrace_get_stack_frame(int frameid, char *output_str, int buffer_len);
+
 #endif	/* __EZTRACE_H__ */
