@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Université Bordeaux 1, Télécom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -10,7 +10,7 @@
 #include <stdint.h>
 
 struct eztrace_array_t {
-  unsigned  item_size;
+  unsigned item_size;
   unsigned nb_items;
   void* values;
   unsigned nb_allocated;
@@ -20,9 +20,8 @@ struct eztrace_array_t {
 #define ITH_VALUE(__i__, __array__) (void*)(((__array__)->values) + ((__i__)*(__array__)->item_size))
 
 /* initialize an array */
-void eztrace_array_create(struct eztrace_array_t* p_array,
-			  unsigned item_size,
-			  unsigned nb_prealloc);
+void eztrace_array_create(struct eztrace_array_t* p_array, unsigned item_size,
+                          unsigned nb_prealloc);
 
 /* free an array */
 void eztrace_array_free(struct eztrace_array_t* p_array);
