@@ -55,9 +55,10 @@ static inline struct eztrace_container_t * get_thread_cont_from_id(
 /* if the verbose option is set (when eztrace_convert is invoked)
  * this prints the name of the current function
  */
-static inline void __func_name(int id, float time, const char* function) {
+static inline void __func_name(int id, int thread_id, float time, const char* function) {
   if (VERBOSE)
-    fprintf(stderr, "[%d] [%f] \t%s\n", id, time, function);
+    fprintf(stderr, "[%d][%x] [%f] \t%s\n", id, thread_id, time, function);
 }
 
+
 #endif	/* EZTRACE_CONVERT_H */
