@@ -192,6 +192,32 @@ void ezt_litl_read_next_event(struct trace_t*p_trace) {
   }
 }
 
+void ezt_litl_read_next_thread_event(struct trace_t *p_trace, litl_tid_t thread_id) {
+  litl_read_process_t* process;
+  litl_read_thread_t* thread;
+  int proc, th;
+  for(proc = 0; proc < p_trace->block->nb_processes; proc++) {
+    process = p_trace->block->processes[proc];
+    for(th = 0; th<process->nb_threads; th++) {
+      thread = process->threads[th];
+      if(thread->thread_pair->tid == thread_id) {
+	litl_read_event_t *p_ev =  litl_read_next_thread_event(p_trace->block,
+							       process,
+							       thread);
+	if(p_ev) {
+	  memcpy(&p_trace->ev, p_ev, sizeof(litl_read_event_t));
+	  p_trace->line_number++;
+	} else {
+	  memset(&p_trace->ev, 0, sizeof(litl_read_event_t));
+	}
+	return;
+      }
+    }
+  }
+  fprintf(stderr, "Error: Cannot find thread %x\n", thread_id);
+  abort();
+}
+
 /* Find the next event to be handled in a trace
  * Return 0 if there is no more event in this trace, or 1 otherwise
  */
@@ -206,6 +232,22 @@ int next_ev(int cur_trace_num) {
   return 1;
 }
 
+
+/* Find the next event to be handled in a trace
+ * Return 0 if there is no more event in this trace, or 1 otherwise
+ */
+int next_thread_ev(int cur_trace_num, litl_tid_t thread_id) {
+  double cur_time = NS_TO_MS(CUR_TIME(cur_trace_num));
+
+  ezt_litl_read_next_thread_event(&traces[cur_trace_num], thread_id);
+  if (!traces[cur_trace_num].ev.event) {
+    traces[cur_trace_num].done = 1;
+    fprintf(stderr, "no more block for trace #%d\n", cur_trace_num);
+    return 0;
+  }
+  return 1;
+}
+
 /* Find the next trace event to handle
  * return the trace id that correspond to the trace to be handled
  */
@@ -1034,6 +1076,9 @@ int process_one_event(eztrace_event_t *ev) {
   if(ret) {
     struct eztrace_container_t *p_cont = GET_PROCESS_CONTAINER(CUR_INDEX);
     p_cont->end_timestamp = CURRENT;
+    struct eztrace_container_t* p_thread = GET_THREAD_CONTAINER(CUR_INDEX, CUR_THREAD_ID);
+    if(p_thread)
+      p_thread->end_timestamp = CURRENT;
   }
 
   if (!ret && NB_START >= NB_TRACES) {
@@ -1190,20 +1235,28 @@ void wake_up_handler_thread() {
   sem_post(&main_thread_sem);
 }
 
-void wait_for_an_event(int trace_index, uint64_t code) {
+void wait_for_an_event_generic(int trace_index, litl_tid_t thread_id, uint64_t code) {
 
   /* This declaration *has to be* before the call to next_ev
    * since next_ev may change the current thread
    */
-  DECLARE_THREAD_INFO(p_thread, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_THREAD_INFO(p_thread, trace_index, thread_id);
 
-  if (!next_ev(trace_index)) {
-    fprintf(stderr, "Warning: trace %d ends, but I am waiting for an event !\n",
-	    trace_index);
-    return;
+  if(thread_id == 0) {
+    if (!next_ev(trace_index)) {
+      fprintf(stderr, "Warning: trace %d ends, but I am waiting for an event !\n",
+	      trace_index);
+      return;
+    }
+  } else {
+    if (!next_thread_ev(trace_index, thread_id)) {
+      fprintf(stderr, "Warning: trace %d ends, but I am waiting for an event !\n",
+	      trace_index);
+      return;
+    }
   }
 
-  if (LITL_READ_GET_CODE(&CUR_TRACE->ev) == code)
+  if (LITL_READ_GET_CODE(&traces[trace_index].ev) == code)
     return;
 
   /* The current thread expects a specific event, but another code appeared.
@@ -1226,7 +1279,7 @@ void wait_for_an_event(int trace_index, uint64_t code) {
   /* wait until the processing thread finds our events */
   sem_wait(&exp_code->semaphore);
   /* make sure the event code is the right one */
-  assert(LITL_READ_GET_CODE(&CUR_TRACE->ev) == code);
+  assert(LITL_READ_GET_CODE(&traces[trace_index].ev) == code);
 
   /* remove the {code,semaphore} from the list of expected events */
   struct expected_code_t* cur_code, *prev_code;
@@ -1251,6 +1304,14 @@ void wait_for_an_event(int trace_index, uint64_t code) {
   p_thread->to_be_killed = 1;
 }
 
+void wait_for_an_event(int trace_index, uint64_t code) {
+  wait_for_an_event_generic(trace_index, 0, code);
+}
+
+void wait_for_an_event_in_cur_thread(uint64_t code) {
+  wait_for_an_event_generic (CUR_INDEX, CUR_THREAD_ID, code);
+}
+
 void new_handler_thread() {
   DECLARE_CUR_THREAD(p_thread);
 
