@@ -42,12 +42,12 @@ const char* eztrace_stats_get_output_dir() {
 }
 
 static struct eztrace_counter* find_counter(eztrace_counter_id counter_id,
-                                            p_eztrace_container p_cont) {
+					    p_eztrace_container p_cont) {
   struct eztrace_counter* counter_array = root_counters;
   if (p_cont)
     counter_array = p_cont->counters;
 
-  int i;
+  unsigned int i;
   for (i = 0; i < nb_counters; i++) {
     if (counter_array[i].id == counter_id)
       return &counter_array[i];
@@ -59,7 +59,7 @@ static struct eztrace_counter* find_counter(eztrace_counter_id counter_id,
  * vector_size items. The names of each of the vector item are stores in names
  */
 void attach_counter(eztrace_counter_id counter_id, unsigned vector_size,
-                    char**names) {
+		    char**names) {
   if (nb_counters >= MAX_COUNTERS) {
     fprintf(stderr, "Too many counters\n");
     exit(1);
@@ -78,7 +78,7 @@ void attach_counter(eztrace_counter_id counter_id, unsigned vector_size,
   cur_counter->values = malloc(sizeof(double) * vector_size);
   cur_counter->value_names = malloc(sizeof(char*) * vector_size);
 
-  int i;
+  unsigned int i;
   /* copy the values names */
   for (i = 0; i < vector_size; i++) {
     asprintf(&(cur_counter->value_names[i]), "%s", names[i]);
@@ -90,7 +90,7 @@ void attach_counter(eztrace_counter_id counter_id, unsigned vector_size,
 
 /* Return a pointer to the vector item #index from the counter #counter_id of a specific container */
 double* get_counter(p_eztrace_container container,
-                    eztrace_counter_id counter_id, unsigned index) {
+		    eztrace_counter_id counter_id, unsigned index) {
   struct eztrace_counter* cur_counter = find_counter(counter_id, container);
   if (cur_counter)
     return &(cur_counter->values[index]);
@@ -102,16 +102,16 @@ void counters_new_container(p_eztrace_container p_cont) {
   assert(p_cont);
 
   p_cont->counters = malloc(sizeof(struct eztrace_counter) * nb_counters);
-  int i;
+  unsigned int i;
   for (i = 0; i < nb_counters; i++) {
     p_cont->counters[i].id = root_counters[i].id;
     p_cont->counters[i].name = root_counters[i].name;
     p_cont->counters[i].nb_values = root_counters[i].nb_values;
     p_cont->counters[i].values = malloc(
-        sizeof(double) * p_cont->counters[i].nb_values);
+	sizeof(double) * p_cont->counters[i].nb_values);
     p_cont->counters[i].value_names = malloc(
-        sizeof(char*) * p_cont->counters[i].nb_values);
-    int j;
+	sizeof(char*) * p_cont->counters[i].nb_values);
+    unsigned int j;
     for (j = 0; j < p_cont->counters[i].nb_values; j++) {
       p_cont->counters[i].values[j] = 0;
       /* don't copy the value name. So be carefull where freeing it! */
@@ -121,7 +121,7 @@ void counters_new_container(p_eztrace_container p_cont) {
 }
 
 static void reduce_counters(p_eztrace_container p_cont,
-                            eztrace_counter_id counter_id) {
+			    eztrace_counter_id counter_id) {
   if (!p_cont)
     return;
 
@@ -129,12 +129,12 @@ static void reduce_counters(p_eztrace_container p_cont,
   assert(counter);
 
   /* for each sub container, reduce its counters and append them to the local counter */
-  int i, j;
+  unsigned int i, j;
   for (i = 0; i < p_cont->nb_children; i++) {
     reduce_counters(p_cont->children[i], counter_id);
 
     struct eztrace_counter* children_counter = find_counter(
-        counter_id, p_cont->children[i]);
+	counter_id, p_cont->children[i]);
     assert(children_counter);
 
     for (j = 0; j < counter->nb_values; j++) {
@@ -144,20 +144,21 @@ static void reduce_counters(p_eztrace_container p_cont,
 }
 
 static void __print_containers_recurse(int depth, eztrace_counter_id id,
-                                       p_eztrace_container p_cont) {
+				       p_eztrace_container p_cont) {
   if (!p_cont)
     return;
   struct eztrace_counter *counter = find_counter(id, p_cont);
   assert(counter);
   /* We assume that the reduction already happened */
 
-  int i;
+  unsigned int i;
   double sum_values = 0;
   /* compute and print the sum of values */
   for (i = 0; i < counter->nb_values; i++) {
     sum_values += counter->values[i];
   }
-  for (i = 0; i < depth; i++)
+  int j = 0;
+  for (j = 0; j < depth; j++)
     printf("   ");
   printf("%s -- \t%s: %lf\t", p_cont->name, counter->name, sum_values);
   /* print each value */
@@ -172,7 +173,8 @@ static void __print_containers_recurse(int depth, eztrace_counter_id id,
 }
 
 static void __print_counter(struct eztrace_counter* counter) {
-  int i, j;
+  unsigned int j;
+  int i;
   /* todo: print the total of counters */
   for (i = 0; i < NB_TRACES; i++) {
     /* reduce each trace counter */
@@ -180,7 +182,7 @@ static void __print_counter(struct eztrace_counter* counter) {
     reduce_counters(p_cont, counter->id);
 
     struct eztrace_counter* children_counter = find_counter(counter->id,
-                                                            p_cont);
+							    p_cont);
     assert(children_counter);
 
     for (j = 0; j < children_counter->nb_values; j++) {
@@ -193,7 +195,7 @@ static void __print_counter(struct eztrace_counter* counter) {
 
 /* Print the values of a specific counter */
 void print_counter(eztrace_counter_id id) {
-  int i;
+  unsigned int i;
 
   for (i = 0; i < nb_counters; i++) {
     if (root_counters[i].id == id)
