@@ -31,7 +31,7 @@ int ezt_getcpu_convert_events(eztrace_event_t *ev) {
 }
 
 
-int ezt_getcpu_convert_stats(eztrace_event_t *ev) {
+int ezt_getcpu_convert_stats(eztrace_event_t *ev __attribute__((unused))) {
   return 0;
 }
 
