@@ -214,9 +214,23 @@ enum coll_type_t {
   mpi_coll_allreduce,
   mpi_coll_reduce_scatter,
   mpi_coll_scan,
-/* todo: add other kinds of collective operations */
+  mpi_coll_type_max,
+  /* todo: add other kinds of collective operations */
 };
 
+#define COLL_TYPE_STR(coll_type)					\
+  (coll_type) == mpi_coll_barrier? "MPI_Barrier":			\
+    (coll_type) == mpi_coll_bcast ? "MPI_Bcast":			\
+    (coll_type) == mpi_coll_gather ? "MPI_Gather":			\
+    (coll_type) == mpi_coll_scatter ? "MPI_Scatter":			\
+    (coll_type) == mpi_coll_allgather ? "MPI_Allgather":		\
+    (coll_type) == mpi_coll_alltoall ? "MPI_Alltoall":			\
+    (coll_type) == mpi_coll_reduce ? "MPI_Reduce":			\
+    (coll_type) == mpi_coll_allreduce ? "MPI_Allreduce":		\
+    (coll_type) == mpi_coll_reduce_scatter ? "MPI_Reduce_scatter":	\
+    (coll_type) == mpi_coll_scan ? "MPI_Scan":				\
+    "MPI_INVALID_COLLECTIV"
+
 enum coll_time_ids {
   start_coll = 0, stop_coll = 2, COLL_NB_TIMES
 };
@@ -233,6 +247,7 @@ struct mpi_coll_msg_t {
   int unexp; /* todo: useless ? */
   char** thread_ids;
   struct mpi_request **requests;
+  int root_process;
 };
 
 /* This structure contains information about a MPI message in
