@@ -13,20 +13,29 @@
 #include "eztrace_hierarchical_array.h"
 #include "eztrace_convert_mpi_coll.h"
 
+static struct ezt_list_t finished_collectives[mpi_coll_type_max];
+
 void init_mpi_coll_messages() {
   hierarchical_array_attach(EZTRACE_MPI_STATS_COLL_MSG_ID,
 			    sizeof(struct coll_msg_event));
 
+  for(int i=0; i<mpi_coll_type_max; i++) {
+    ezt_list_new(&finished_collectives[i]);
+  }
 }
 
 void print_coll_stats();
 
+
+void __print_coll_message_header(FILE*stream) {
+  fprintf(stream, "#[ID]\tCollective_type\troot_rank\t[rank_0_thread enter_timestamp exit_timestamp] [rank_1_thread enter_timestamp exit_timestamp]...\n");
+}
+
 void __print_coll_message(FILE*stream, struct mpi_coll_msg_t *msg) {
-  fprintf(stream, "[%p]\ttype %d\n", msg, msg->type);
+  fprintf(stream, "[%p]\t%s\t%d\t", msg, COLL_TYPE_STR(msg->type), msg->root_process);
   int i;
   for (i = 0; i < msg->comm_size; i++) {
-    fprintf(stream, "\t");
-    fprintf(stream, "[%s] enter %lu\tleave: %lu\n", msg->thread_ids[i],
+    fprintf(stream, "[%s %lu %lu] ", msg->thread_ids[i],
             msg->times[i][start_coll], msg->times[i][stop_coll]);
   }
   fprintf(stream, "\n");
@@ -49,6 +58,38 @@ void __print_coll_messages(FILE*stream) {
   }
 }
 
+void ezt_mpi_dump_coll_messages(FILE* stream) {
+  for(int i=0; i<mpi_coll_type_max; i++) {
+    struct ezt_list_t*l = &finished_collectives[i];
+    struct ezt_list_token_t *token;
+
+    if(l->nb_item > 0) {
+      char* path;
+      int ret = asprintf(&path, "%s/mpi_collective_message_dump_%s",
+			 eztrace_stats_get_output_dir(), COLL_TYPE_STR(i));
+
+      FILE *f = fopen(path, "w");
+      if (!f) {
+	perror("Error while dumping collective messages");
+      }
+
+      __print_coll_message_header(f);
+      ezt_list_foreach(l, token) {
+	struct mpi_pending_coll_comm* p_comm = (struct mpi_pending_coll_comm*) token->data;
+	struct mpi_coll_msg_t* msg = p_comm->msg;
+	__print_coll_message(f, msg);
+      }
+
+      ret = fclose(f);
+      if (ret) {
+	perror("Error while dumping collective messages (fclose)");
+      }
+      printf("\tMPI collective messages dumped in '%s'\n", path);
+      free(path);
+    }
+  }
+}
+
 /* create a new collective message */
 static struct mpi_coll_msg_t* __new_coll_message(enum coll_type_t type,
 						 struct ezt_mpi_comm *comm,
@@ -68,6 +109,7 @@ static struct mpi_coll_msg_t* __new_coll_message(enum coll_type_t type,
   msg->link_id = malloc(sizeof(char**) * comm_size);
   msg->requests = malloc(sizeof(struct mpi_request *) * comm_size);
   msg->nb_started = 0;
+  msg->root_process = -1;
   for (i = 0; i < comm_size; i++) {
     int j;
     msg->comm[i] = NULL;
@@ -223,6 +265,7 @@ static int __get_local_rank(int global_rank,
     if(is_comm_mine(global_rank, comm))
       return comm->my_rank;
   }
+  return -1;
 }
 
 struct mpi_coll_msg_t*
@@ -333,7 +376,23 @@ __leave_coll(uint64_t time,
 
   /* remove the collective from the list of pending collectives */
   ezt_list_remove(&pending_comm->token);
-  free(pending_comm);
+
+  int nb_completed=0;
+  for(int i=0; i<comm->comm_size; i++) {
+    if(msg->times[i][stop_coll] != TIME_INIT)
+      nb_completed++;
+  }
+  if(nb_completed == comm->comm_size) {
+
+    free(pending_comm);
+    struct mpi_pending_coll_comm *finished_comm = malloc(sizeof(struct mpi_pending_coll_comm));
+    finished_comm->msg = msg;
+    finished_comm->token.data = finished_comm;
+
+    ezt_list_add(&finished_collectives[type], &finished_comm->token);
+  } else {
+    free(pending_comm);
+  }
 
   __store_finished_collective(GET_PROCESS_CONTAINER(comm->ranks[comm->my_rank]),
 			      time,
