@@ -1,4 +1,4 @@
-/* -*- c-file-style: "GNU" -*- */
+/* -*- C-File-style: "GNU" -*- */
 /*
  * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
@@ -53,16 +53,16 @@ int (*libMPI_Comm_split_type)(MPI_Comm comm, int split_type, int key, MPI_Info i
 			      MPI_Comm * newcomm);
 
 int (*libMPI_Intercomm_create)(MPI_Comm local_comm, int local_leader,
-                               MPI_Comm peer_comm, int remote_leader, int tag,
-                               MPI_Comm *newintercomm);
+			       MPI_Comm peer_comm, int remote_leader, int tag,
+			       MPI_Comm *newintercomm);
 int (*libMPI_Intercomm_merge)(MPI_Comm intercomm, int high,
-                              MPI_Comm *newintracomm);
+			      MPI_Comm *newintracomm);
 int (*libMPI_Cart_sub)(MPI_Comm old_comm, CONST int *belongs,
-                       MPI_Comm *new_comm);
+		       MPI_Comm *new_comm);
 int (*libMPI_Cart_create)(MPI_Comm comm_old, int ndims, CONST int *dims,
-                          CONST int *periods, int reorder, MPI_Comm *comm_cart);
+			  CONST int *periods, int reorder, MPI_Comm *comm_cart);
 int (*libMPI_Graph_create)(MPI_Comm comm_old, int nnodes, CONST int *index,
-                           CONST int *edges, int reorder, MPI_Comm *comm_graph);
+			   CONST int *edges, int reorder, MPI_Comm *comm_graph);
 
 int (*libMPI_Dist_graph_create_adjacent)(MPI_Comm comm_old,
 					 int indegree,
@@ -80,38 +80,38 @@ int (*libMPI_Dist_graph_create)(MPI_Comm comm_old, int n, CONST int sources[],
 				MPI_Comm *comm_dist_graph);
 
 int (*libMPI_Send)(CONST void *buf, int count, MPI_Datatype datatype, int dest,
-                   int tag, MPI_Comm comm);
+		   int tag, MPI_Comm comm);
 int (*libMPI_Recv)(void *buf, int count, MPI_Datatype datatype, int source,
-                   int tag, MPI_Comm comm, MPI_Status *status);
+		   int tag, MPI_Comm comm, MPI_Status *status);
 
 int (*libMPI_Bsend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm);
 int (*libMPI_Ssend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm);
 int (*libMPI_Rsend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm);
 int (*libMPI_Isend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                    MPI_Request *);
+		    MPI_Request *);
 int (*libMPI_Ibsend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                     MPI_Request *);
+		     MPI_Request *);
 int (*libMPI_Issend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                     MPI_Request *);
+		     MPI_Request *);
 int (*libMPI_Irsend)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                     MPI_Request *);
+		     MPI_Request *);
 int (*libMPI_Irecv)(void*, int, MPI_Datatype, int, int, MPI_Comm, MPI_Request *);
 
 int (*libMPI_Sendrecv)(CONST void *, int, MPI_Datatype, int, int, void *, int,
-                       MPI_Datatype, int, int, MPI_Comm, MPI_Status *);
+		       MPI_Datatype, int, int, MPI_Comm, MPI_Status *);
 int (*libMPI_Sendrecv_replace)(void*, int, MPI_Datatype, int, int, int, int,
-                               MPI_Comm, MPI_Status *);
+			       MPI_Comm, MPI_Status *);
 
 int (*libMPI_Send_init)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                        MPI_Request *);
+			MPI_Request *);
 int (*libMPI_Bsend_init)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                         MPI_Request *);
+			 MPI_Request *);
 int (*libMPI_Ssend_init)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                         MPI_Request *);
+			 MPI_Request *);
 int (*libMPI_Rsend_init)(CONST void*, int, MPI_Datatype, int, int, MPI_Comm,
-                         MPI_Request *);
+			 MPI_Request *);
 int (*libMPI_Recv_init)(void*, int, MPI_Datatype, int, int, MPI_Comm,
-                        MPI_Request *);
+			MPI_Request *);
 int (*libMPI_Start)(MPI_Request *);
 int (*libMPI_Startall)(int, MPI_Request *);
 
@@ -126,31 +126,31 @@ int (*libMPI_Testsome)(int, MPI_Request *, int *, int *, MPI_Status *);
 
 int (*libMPI_Probe)(int source, int tag, MPI_Comm comm, MPI_Status *status);
 int (*libMPI_Iprobe)(int source, int tag, MPI_Comm comm, int *flag,
-                     MPI_Status *status);
+		     MPI_Status *status);
 
 int (*libMPI_Barrier)( MPI_Comm);
 int (*libMPI_Bcast)(void*, int, MPI_Datatype, int, MPI_Comm);
 int (*libMPI_Gather)(CONST void*, int, MPI_Datatype, void*, int, MPI_Datatype,
-                     int, MPI_Comm);
+		     int, MPI_Comm);
 int (*libMPI_Gatherv)(CONST void*, int, MPI_Datatype, void*, CONST int *,
-                      CONST int *, MPI_Datatype, int, MPI_Comm);
+		      CONST int *, MPI_Datatype, int, MPI_Comm);
 int (*libMPI_Scatter)(CONST void*, int, MPI_Datatype, void*, int, MPI_Datatype,
-                      int, MPI_Comm);
+		      int, MPI_Comm);
 int (*libMPI_Scatterv)(CONST void*, CONST int *, CONST int *, MPI_Datatype,
-                       void*, int, MPI_Datatype, int, MPI_Comm);
+		       void*, int, MPI_Datatype, int, MPI_Comm);
 int (*libMPI_Allgather)(CONST void*, int, MPI_Datatype, void*, int,
-                        MPI_Datatype, MPI_Comm);
+			MPI_Datatype, MPI_Comm);
 int (*libMPI_Allgatherv)(CONST void*, int, MPI_Datatype, void*, CONST int *,
-                         CONST int *, MPI_Datatype, MPI_Comm);
+			 CONST int *, MPI_Datatype, MPI_Comm);
 int (*libMPI_Alltoall)(CONST void*, int, MPI_Datatype, void*, int, MPI_Datatype,
-                       MPI_Comm);
+		       MPI_Comm);
 int (*libMPI_Alltoallv)(CONST void*, CONST int *, CONST int *, MPI_Datatype,
-                        void*, CONST int *, CONST int *, MPI_Datatype, MPI_Comm);
+			void*, CONST int *, CONST int *, MPI_Datatype, MPI_Comm);
 int (*libMPI_Reduce)(CONST void*, void*, int, MPI_Datatype, MPI_Op, int,
-                     MPI_Comm);
+		     MPI_Comm);
 int (*libMPI_Allreduce)(CONST void*, void*, int, MPI_Datatype, MPI_Op, MPI_Comm);
 int (*libMPI_Reduce_scatter)(CONST void*, void*, CONST int *, MPI_Datatype,
-                             MPI_Op, MPI_Comm);
+			     MPI_Op, MPI_Comm);
 int (*libMPI_Scan)(CONST void*, void*, int, MPI_Datatype, MPI_Op, MPI_Comm);
 
 /* non-blocking collective (available since MPI 3.0) */
@@ -178,13 +178,13 @@ int ( *libMPI_Put) (CONST void *, int, MPI_Datatype, int, MPI_Aint, int, MPI_Dat
 			   MPI_Win);
 
 int (*libMPI_Get)(void *, int, MPI_Datatype, int, MPI_Aint, int, MPI_Datatype,
-                  MPI_Win);
+		  MPI_Win);
 int (*libMPI_Put)(CONST void *, int, MPI_Datatype, int, MPI_Aint, int,
-                  MPI_Datatype, MPI_Win);
+		  MPI_Datatype, MPI_Win);
 
 int (*libMPI_Comm_spawn)(CONST char *command, char *argv[], int maxprocs,
-                         MPI_Info info, int root, MPI_Comm comm,
-                         MPI_Comm *intercomm, int array_of_errcodes[]);
+			 MPI_Info info, int root, MPI_Comm comm,
+			 MPI_Comm *intercomm, int array_of_errcodes[]);
 
 /* fortran bindings */
 void (*libmpi_init_)(int*e);
@@ -221,26 +221,26 @@ int (*libmpi_dist_graph_create_)(int*, int*, int*,int*, int*, int*,int*, int*, i
 
 void (*libmpi_send_)(void*, int*, MPI_Datatype*, int*, int*, int*);
 void (*libmpi_recv_)(void*, int*, MPI_Datatype*, int*, int *, MPI_Status *,
-                     int*);
+		     int*);
 
 void (*libmpi_sendrecv_)(void *, int, MPI_Datatype, int, int, void *, int,
-                         MPI_Datatype, int, int, MPI_Comm, MPI_Status *, int*);
+			 MPI_Datatype, int, int, MPI_Comm, MPI_Status *, int*);
 void (*libmpi_sendrecv_replace_)(void*, int, MPI_Datatype, int, int, int, int,
-                                 MPI_Comm, MPI_Status *, int*);
+				 MPI_Comm, MPI_Status *, int*);
 
 void (*libmpi_bsend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*, int*);
 void (*libmpi_ssend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*, int*);
 void (*libmpi_rsend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*, int*);
 void (*libmpi_isend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                      MPI_Request*, int*);
+		      MPI_Request*, int*);
 void (*libmpi_ibsend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                       MPI_Request*, int*);
+		       MPI_Request*, int*);
 void (*libmpi_issend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                       MPI_Request *, int*);
+		       MPI_Request *, int*);
 void (*libmpi_irsend_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                       MPI_Request *, int*);
+		       MPI_Request *, int*);
 void (*libmpi_irecv_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                      MPI_Request *, int*);
+		      MPI_Request *, int*);
 
 void (*libmpi_wait_)(MPI_Request*, MPI_Status*, int*);
 void (*libmpi_test_)(MPI_Request*, int*, MPI_Status*, int*);
@@ -252,40 +252,40 @@ void (*libmpi_waitsome_)(int*, MPI_Request *, int *, int *, MPI_Status *, int*);
 void (*libmpi_testsome_)(int*, MPI_Request *, int *, int *, MPI_Status *, int*);
 
 void (*libmpi_probe_)(int* source, int* tag, MPI_Comm* comm, MPI_Status *status,
-                      int* err);
+		      int* err);
 void (*libmpi_iprobe_)(int* source, int* tag, MPI_Comm* comm, int *flag,
-                       MPI_Status *status, int* err);
+		       MPI_Status *status, int* err);
 
 void (*libmpi_get_)(void *, int*, MPI_Datatype*, int*, MPI_Aint*, int*,
-                    MPI_Datatype*, MPI_Win*, int*);
+		    MPI_Datatype*, MPI_Win*, int*);
 void (*libmpi_put_)(void *, int*, MPI_Datatype*, int*, MPI_Aint*, int*,
-                    MPI_Datatype*, MPI_Win*, int*);
+		    MPI_Datatype*, MPI_Win*, int*);
 
 void (*libmpi_bcast_)(void*, int*, MPI_Datatype*, int*, MPI_Comm*, int*);
 void (*libmpi_gather_)(void*, int*, MPI_Datatype*, void*, int*, MPI_Datatype*,
-                       int*, MPI_Comm*, int*);
+		       int*, MPI_Comm*, int*);
 void (*libmpi_gatherv_)(void*, int*, MPI_Datatype*, void*, int*, int*,
-                        MPI_Datatype*, int*, MPI_Comm*);
+			MPI_Datatype*, int*, MPI_Comm*);
 void (*libmpi_scatter_)(void*, int*, MPI_Datatype*, void*, int*, MPI_Datatype*,
-                        int*, MPI_Comm*, int*);
+			int*, MPI_Comm*, int*);
 void (*libmpi_scatterv_)(void*, int*, int*, MPI_Datatype*, void*, int*,
-                         MPI_Datatype*, int*, MPI_Comm*, int*);
+			 MPI_Datatype*, int*, MPI_Comm*, int*);
 void (*libmpi_allgather_)(void*, int*, MPI_Datatype*, void*, int*,
-                          MPI_Datatype*, MPI_Comm*, int*);
+			  MPI_Datatype*, MPI_Comm*, int*);
 void (*libmpi_allgatherv_)(void*, int*, MPI_Datatype*, void*, int*, int*,
-                           MPI_Datatype*, MPI_Comm*);
+			   MPI_Datatype*, MPI_Comm*);
 void (*libmpi_alltoall_)(void*, int*, MPI_Datatype*, void*, int*, MPI_Datatype*,
-                         MPI_Comm*, int*);
+			 MPI_Comm*, int*);
 void (*libmpi_alltoallv_)(void*, int*, int*, MPI_Datatype*, void*, int*, int*,
-                          MPI_Datatype*, MPI_Comm*, int*);
+			  MPI_Datatype*, MPI_Comm*, int*);
 void (*libmpi_reduce_)(void*, void*, int*, MPI_Datatype*, MPI_Op*, int*,
-                       MPI_Comm*, int*);
+		       MPI_Comm*, int*);
 void (*libmpi_allreduce_)(void*, void*, int*, MPI_Datatype*, MPI_Op*, MPI_Comm*,
-                          int*);
+			  int*);
 void (*libmpi_reduce_scatter_)(void*, void*, int*, MPI_Datatype*, MPI_Op*,
-                               MPI_Comm*, int*);
+			       MPI_Comm*, int*);
 void (*libmpi_scan_)(void*, void*, int*, MPI_Datatype*, MPI_Op*, MPI_Comm*,
-                     int*);
+		     int*);
 
 #ifdef USE_MPI3
 /* non-blocking collective (available since MPI 3.0) */
@@ -306,31 +306,30 @@ void (*libmpi_iscan_)(const void*, void*, int*, MPI_Fint*, MPI_Op, MPI_Fint*, MP
 #endif
 
 void (*libmpi_comm_spawn_)(char *command, char **argv, int *maxprocs,
-                           MPI_Info *info, int *root, MPI_Comm *comm,
-                           MPI_Comm *intercomm, int *array_of_errcodes,
-                           int*error);
+			   MPI_Info *info, int *root, MPI_Comm *comm,
+			   MPI_Comm *intercomm, int *array_of_errcodes,
+			   int*error);
 
 void (*libmpi_send_init_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                          MPI_Request *, int*);
+			  MPI_Request *, int*);
 void (*libmpi_bsend_init_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                           MPI_Request *, int*);
+			   MPI_Request *, int*);
 void (*libmpi_ssend_init_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                           MPI_Request *, int*);
+			   MPI_Request *, int*);
 void (*libmpi_rsend_init_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                           MPI_Request *, int*);
+			   MPI_Request *, int*);
 void (*libmpi_recv_init_)(void*, int*, MPI_Datatype*, int*, int*, MPI_Comm*,
-                          MPI_Request *, int*);
+			  MPI_Request *, int*);
 void (*libmpi_start_)(MPI_Request *, int*);
 void (*libmpi_startall_)(int*, MPI_Request *, int*);
 
-
 struct __ezt_mpi_info {
   int rank;
   int size;
-  app_ptr mpi_any_source;
-  app_ptr mpi_any_tag;
+  int mpi_any_source;
+  int mpi_any_tag;
   app_ptr mpi_request_null;
-  app_ptr mpi_proc_null;
+  int mpi_proc_null;
   app_ptr mpi_comm_world;
   app_ptr mpi_comm_self;
   int ppid;
@@ -356,8 +355,8 @@ static struct __ezt_mpi_info mpi_infos;
  * callback) with the same args
  */
 int MPI_Comm_spawn(CONST char *command, char *argv[], int maxprocs,
-                   MPI_Info info, int root, MPI_Comm comm, MPI_Comm *intercomm,
-                   int array_of_errcodes[]) {
+		   MPI_Info info, int root, MPI_Comm comm, MPI_Comm *intercomm,
+		   int array_of_errcodes[]) {
   /* Instead of running command argv, we have to
    run 'env LD_PRELOAD=xxx command argv'
    Thus, we have to provide a new argv array
@@ -388,7 +387,7 @@ int MPI_Comm_spawn(CONST char *command, char *argv[], int maxprocs,
   new_argv[i + 2] = NULL;
 
   ret = libMPI_Comm_spawn("env", new_argv, maxprocs, info, root, comm,
-                          intercomm, array_of_errcodes);
+			  intercomm, array_of_errcodes);
 
   /* Now that the processes are launched, tell them our proc_id so that the filenames are not messed up */
   int f_size; /* number of children actually created */
@@ -396,7 +395,7 @@ int MPI_Comm_spawn(CONST char *command, char *argv[], int maxprocs,
   int my_pid = getpid();
   MPI_Comm_remote_size(*intercomm, &f_size);
 
-  EZTRACE_EVENT_PACKED_2(EZTRACE_MPI_SPAWN, my_pid, f_size);
+  EZTRACE_EVENT_FORCE_RECORD_PACKED_2(EZTRACE_MPI_SPAWN, my_pid, f_size);
 
   for (i = 0; i < f_size; i++) {
     MPI_Send(&proc_id_len, 1, MPI_INTEGER, i, 0, *intercomm);
@@ -441,7 +440,7 @@ int MPI_Finalize() {
 void ezt_mpi_initialize_trace();
 
 /* internal function
- * This function is used by the various MPI_Init* functions (C 
+ * This function is used by the various MPI_Init* functions (C
  * and Fortran versions)
  * This function add informations to the trace (rank, etc.)
  * and set the trace filename.
@@ -455,7 +454,6 @@ void __mpi_init_generic() {
   libMPI_Comm_size(MPI_COMM_WORLD, &mpi_infos.size);
   libMPI_Comm_rank(MPI_COMM_WORLD, &mpi_infos.rank);
 
-  char* filename = NULL;
   if (parentcomm == MPI_COMM_NULL) {
     /* This process is a 'normal' process (ie. it wasn't spawned) */
     ret = asprintf(&mpi_infos.proc_id, "%d", mpi_infos.rank);
@@ -469,10 +467,10 @@ void __mpi_init_generic() {
 
     /* Get the parent process id */
     libMPI_Recv(&father_proc_id_len, 1, MPI_INTEGER, 0, 0, parentcomm,
-                MPI_STATUS_IGNORE);
+		MPI_STATUS_IGNORE);
     father_proc_id = (char*) malloc(sizeof(char) * father_proc_id_len);
     libMPI_Recv(father_proc_id, father_proc_id_len, MPI_CHAR, 0, 0, parentcomm,
-                MPI_STATUS_IGNORE);
+		MPI_STATUS_IGNORE);
 
     libMPI_Recv(&mpi_infos.ppid, 1, MPI_INTEGER, 0, 0, parentcomm, MPI_STATUS_IGNORE);
 
@@ -485,9 +483,9 @@ void __mpi_init_generic() {
   mpi_infos.mpi_any_source=MPI_ANY_SOURCE;
   mpi_infos.mpi_any_tag = MPI_ANY_TAG;
   mpi_infos.mpi_proc_null = MPI_PROC_NULL;
-  mpi_infos.mpi_request_null = MPI_REQUEST_NULL;
-  mpi_infos.mpi_comm_world = MPI_COMM_WORLD;
-  mpi_infos.mpi_comm_self = MPI_COMM_SELF;
+  mpi_infos.mpi_request_null = (app_ptr)MPI_REQUEST_NULL;
+  mpi_infos.mpi_comm_world = (app_ptr)MPI_COMM_WORLD;
+  mpi_infos.mpi_comm_self = (app_ptr)MPI_COMM_SELF;
 
   __mpi_init_called = 1;
   ezt_mpi_initialize_trace();
@@ -498,25 +496,26 @@ void __mpi_init_generic() {
  */
 void ezt_mpi_initialize_trace() {
   static int mpi_trace_initialized = 0;
-  if(__ezt_trace.status == ezt_trace_status_running) {
+  if(__ezt_trace.status == ezt_trace_status_running
+     || __ezt_trace.status == ezt_trace_status_paused) {
     if (!mpi_trace_initialized) {
 
       assert(__mpi_init_called);
 
       mpi_trace_initialized = 1;
       if (mpi_infos.ppid>=0)
-	EZTRACE_EVENT_PACKED_2(EZTRACE_MPI_SPAWNED, mpi_infos.ppid, mpi_infos.rank);
+	EZTRACE_EVENT_FORCE_RECORD_PACKED_2(EZTRACE_MPI_SPAWNED, mpi_infos.ppid, mpi_infos.rank);
 
       char *filename= NULL;
-      int ret = asprintf(&filename, "eztrace_log_rank_%s", mpi_infos.proc_id);
+      asprintf(&filename, "eztrace_log_rank_%s", mpi_infos.proc_id);
       eztrace_set_filename(filename);
 
-      EZTRACE_EVENT_PACKED_6(EZTRACE_MPI_INIT, mpi_infos.rank, mpi_infos.size,
+      EZTRACE_EVENT_FORCE_RECORD_PACKED_6(EZTRACE_MPI_INIT, mpi_infos.rank, mpi_infos.size,
 			     mpi_infos.mpi_any_source, mpi_infos.mpi_any_tag,
 			     (app_ptr)mpi_infos.mpi_request_null,
 			     mpi_infos.mpi_proc_null);
 
-      EZTRACE_EVENT_PACKED_2(EZTRACE_MPI_INIT_Info,
+      EZTRACE_EVENT_FORCE_RECORD_PACKED_2(EZTRACE_MPI_INIT_Info,
 			     (app_ptr)mpi_infos.mpi_comm_world,
 			     (app_ptr)mpi_infos.mpi_comm_self);
     }
@@ -557,12 +556,12 @@ static void __ezt_new_mpi_comm(MPI_Comm comm) {
 
   /* translate the ranks of the local group into rank of the world group */
   MPI_Group_translate_ranks(group, gsize, local_ranks, world_group,
-                            global_ranks);
+			    global_ranks);
 
   /* record the information we need to use the communicator */
-  EZTRACE_EVENT_PACKED_2(EZTRACE_MPI_NEW_COMM,  (app_ptr)comm, gsize);
+  EZTRACE_EVENT_FORCE_RECORD_PACKED_2(EZTRACE_MPI_NEW_COMM,  (app_ptr)comm, gsize);
   for (i = 0; i < gsize; i++) {
-    EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_NEW_COMM_Info, global_ranks[i]);
+    EZTRACE_EVENT_FORCE_RECORD_PACKED_1(EZTRACE_MPI_NEW_COMM_Info, global_ranks[i]);
   }
 }
 
@@ -595,14 +594,15 @@ static void __ezt_new_mpi_comm(MPI_Comm comm) {
 int MPI_Comm_disconnect(MPI_Comm * comm) {
   FUNCTION_ENTRY;
   if (comm)
-    EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_DELETE_COMM,  (app_ptr)*comm);
+    EZTRACE_EVENT_FORCE_RECORD_PACKED_1(EZTRACE_MPI_DELETE_COMM,  (app_ptr)*comm);
   return libMPI_Comm_disconnect(comm);
 }
 
 int MPI_Comm_free(MPI_Comm *comm) {
   FUNCTION_ENTRY;
+
   if (comm)
-    EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_DELETE_COMM,  (app_ptr)*comm);
+    EZTRACE_EVENT_FORCE_RECORD_PACKED_1(EZTRACE_MPI_DELETE_COMM,  (app_ptr)*comm);
   return libMPI_Comm_free(comm);
 }
 
@@ -642,7 +642,7 @@ int MPI_Comm_dup_with_info(MPI_Comm comm, MPI_Info info, MPI_Comm * newcomm) {
 }
 
 int MPI_Comm_split_type(MPI_Comm comm, int split_type, int key, MPI_Info info,
-                        MPI_Comm * newcomm) {
+			MPI_Comm * newcomm) {
   FUNCTION_ENTRY;
   int ret = libMPI_Comm_split_type(comm, split_type, key, info, newcomm);
   __EZT_NEW_COMM(*newcomm, comm);
@@ -650,11 +650,11 @@ int MPI_Comm_split_type(MPI_Comm comm, int split_type, int key, MPI_Info info,
 }
 
 int MPI_Intercomm_create(MPI_Comm local_comm, int local_leader,
-                         MPI_Comm peer_comm, int remote_leader, int tag,
-                         MPI_Comm *newintercomm) {
+			 MPI_Comm peer_comm, int remote_leader, int tag,
+			 MPI_Comm *newintercomm) {
   FUNCTION_ENTRY;
   int ret = libMPI_Intercomm_create(local_comm, local_leader, peer_comm,
-                                    remote_leader, tag, newintercomm);
+				    remote_leader, tag, newintercomm);
   __EZT_NEW_COMM(*newintercomm, local_comm);
   return ret;
 }
@@ -675,21 +675,21 @@ int MPI_Cart_sub(MPI_Comm old_comm, CONST int *belongs, MPI_Comm *new_comm)
 }
 
 int MPI_Cart_create(MPI_Comm comm_old, int ndims, CONST int *dims,
-                    CONST int *periods, int reorder, MPI_Comm *comm_cart)
+		    CONST int *periods, int reorder, MPI_Comm *comm_cart)
 {
   FUNCTION_ENTRY;
   int ret = libMPI_Cart_create(comm_old, ndims, dims, periods, reorder,
-                               comm_cart);
+			       comm_cart);
   __EZT_NEW_COMM(*comm_cart, old_comm);
   return ret;
 }
 
 int MPI_Graph_create(MPI_Comm comm_old, int nnodes, CONST int *index,
-                     CONST int *edges, int reorder, MPI_Comm *comm_graph)
+		     CONST int *edges, int reorder, MPI_Comm *comm_graph)
 {
   FUNCTION_ENTRY;
   int ret = libMPI_Graph_create(comm_old, nnodes, index, edges, reorder,
-                                comm_graph);
+				comm_graph);
   __EZT_NEW_COMM(*comm_graph, old_comm);
   return ret;
 }
@@ -713,13 +713,13 @@ int MPI_Dist_graph_create(MPI_Comm comm_old,
 }
 
 int MPI_Dist_graph_create_adjacent(MPI_Comm comm_old,
-                                   int indegree,
+				   int indegree,
 				   CONST int sources[],
-                                   CONST int sourceweights[],
-                                   int outdegree,
+				   CONST int sourceweights[],
+				   int outdegree,
 				   CONST int destinations[],
-                                   CONST int destweights[],
-                                   MPI_Info info,
+				   CONST int destweights[],
+				   MPI_Info info,
 				   int reorder,
 				   MPI_Comm *comm_dist_graph) {
   FUNCTION_ENTRY;
@@ -732,7 +732,8 @@ int MPI_Dist_graph_create_adjacent(MPI_Comm comm_old,
 }
 
 
-START_INTERCEPT INTERCEPT2("MPI_Init_thread", libMPI_Init_thread)
+START_INTERCEPT_MODULE(mpi)
+INTERCEPT2("MPI_Init_thread", libMPI_Init_thread)
 INTERCEPT2("MPI_Init", libMPI_Init)
 INTERCEPT2("MPI_Finalize", libMPI_Finalize)
 INTERCEPT2("MPI_Barrier", libMPI_Barrier)
@@ -927,12 +928,12 @@ INTERCEPT2("mpi_rsend_init_", libmpi_rsend_init_)
 INTERCEPT2("mpi_recv_init_", libmpi_recv_init_)
 INTERCEPT2("mpi_start_", libmpi_start_)
 INTERCEPT2("mpi_startall_", libmpi_startall_)
-END_INTERCEPT
+END_INTERCEPT_MODULE(mpi)
 
 void libinit(void) __attribute__ ((constructor));
 void libinit(void) {
 
-  DYNAMIC_INTERCEPT_ALL();
+  DYNAMIC_INTERCEPT_ALL_MODULE(mpi);
 
 #ifdef EZTRACE_AUTOSTART
   eztrace_start ();
