@@ -40,7 +40,7 @@ static void MPI_Allgatherv_prolog (CONST void *sendbuf __attribute__((unused)),
   MPI_Type_size(sendtype, &dsize);
   int data_size = sendcount * dsize;
 
-  EZTRACE_EVENT_PACKED_d(EZTRACE_MPI_START_Allgatherv, (app_ptr)comm, size, rank, data_size);
+  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_Allgatherv, (app_ptr)comm, size, rank, data_size);
 }
 
 static int MPI_Allgatherv_core (CONST void *sendbuf __attribute__((unused)),
