@@ -43,8 +43,9 @@ static void MPI_Ialltoallv_prolog (CONST void *sendbuf __attribute__((unused)),
   int ssize, rsize;
   MPI_Type_size(sendtype, &ssize);
   MPI_Type_size(recvtype, &rsize);
+  int data_size = sendcnts[0] * ssize;
 
-  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_IALLTOALLV, (app_ptr)comm, size, rank, (app_ptr)r);
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_IALLTOALLV, (app_ptr)comm, size, rank, (app_ptr)r, data_size);
 }
 
 static int MPI_Ialltoallv_core (CONST void *sendbuf, CONST int *sendcnts, CONST int *sdispls, MPI_Datatype sendtype,
