@@ -1,6 +1,6 @@
 /* -*- c-file-style: "GNU" -*- */
 /*
- * Copyright © CNRS, INRIA, Université Bordeaux 1
+ * Copyright (C) CNRS, INRIA, Universite Bordeaux 1, Telecom SudParis
  * See COPYING in top-level directory.
  */
 
@@ -21,24 +21,19 @@
 #include "mpi_ev_codes.h"
 #include "eztrace.h"
 
-
-
-static int MPI_Iprobe_core( int source, int tag, MPI_Comm comm, int *flag, MPI_Status *status )
-{
+static int MPI_Iprobe_core(int source, int tag, MPI_Comm comm, int *flag,
+                           MPI_Status *status) {
   return libMPI_Iprobe(source, tag, comm, flag, status);
 }
 
-
-static void MPI_Iprobe_epilog( int source __attribute__((unused)),
-			       int tag __attribute__((unused)),
-			       MPI_Comm comm __attribute__((unused)),
-			       int *flag,
-			       MPI_Status *status )
-{
-  if(*flag) {
+static void MPI_Iprobe_epilog(int source __attribute__((unused)),
+                              int tag __attribute__((unused)),
+                              MPI_Comm comm __attribute__((unused)), int *flag,
+                              MPI_Status *status) {
+  if (*flag) {
     int length = -1;
     MPI_Get_count(status, MPI_BYTE, &length);
-    EZTRACE_EVENT3(FUT_MPI_IPROBE_SUCCESS, status->MPI_SOURCE, status->MPI_TAG, length);
+    EZTRACE_EVENT_PACKED_3(EZTRACE_MPI_IPROBE_SUCCESS, status->MPI_SOURCE, status->MPI_TAG, length);
   }
 #if 0
   /* comment out in order to avoid spamming the output trace
@@ -46,14 +41,14 @@ static void MPI_Iprobe_epilog( int source __attribute__((unused)),
    * do { iprobe(); } while(!success);
    */
   else {
-    EZTRACE_EVENT2(FUT_MPI_IPROBE_FAILED, source, tag);
+   EZTRACE_EVENT_PACKED_2(EZTRACE_MPI_IPROBE_FAILED, source, tag);
   }
 #endif
 
 }
 
-int MPI_Iprobe( int source, int tag, MPI_Comm comm, int *flag, MPI_Status *status )
-{
+int MPI_Iprobe(int source, int tag, MPI_Comm comm, int *flag,
+               MPI_Status *status) {
   FUNCTION_ENTRY;
   int ret = MPI_Iprobe_core(source, tag, comm, flag, status);
   MPI_Iprobe_epilog(source, tag, comm, flag, status);
@@ -61,9 +56,9 @@ int MPI_Iprobe( int source, int tag, MPI_Comm comm, int *flag, MPI_Status *statu
   return ret;
 }
 
-
-void mpif_iprobe_( int* source, int* tag, MPI_Fint* comm, int *flag, MPI_Status *status, int* err )
-{
+void mpif_iprobe_(int* source, int* tag, MPI_Fint* comm, int *flag,
+                  MPI_Status *status, int* err) {
+  FUNCTION_ENTRY;
   MPI_Comm c_comm = MPI_Comm_f2c(*comm);
   *err = MPI_Iprobe_core(*source, *tag, c_comm, flag, status);
   MPI_Iprobe_epilog(*source, *tag, c_comm, flag, status);
