@@ -23,30 +23,39 @@
 
 
 #ifdef USE_MPI3
-static int MPI_Ireduce_scatter_core (CONST void *sendbuf, void *recvbuf, CONST int *recvcnts,
-				     MPI_Datatype datatype, MPI_Op op, MPI_Comm comm,
-				     MPI_Request *r)
-{
-  return libMPI_Ireduce_scatter (sendbuf, recvbuf, recvcnts, datatype, op, comm, r);
-}
-
-static void MPI_Ireduce_scatter_epilog (CONST void *sendbuf __attribute__((unused)),
-				       void *recvbuf __attribute__((unused)),
-				       CONST int *recvcnts __attribute__((unused)),
+static void MPI_Ireduce_scatter_prolog (CONST void *sendbuf __attribute__((unused)),
+					void *recvbuf __attribute__((unused)),
+					CONST int *recvcnts __attribute__((unused)),
 					MPI_Datatype datatype,
 					MPI_Op op __attribute__((unused)),
 					MPI_Comm comm,
-					MPI_Request *r)
-{
+					MPI_Request *r) {
   int rank = -1;
   int size = -1;
   libMPI_Comm_size(comm, &size);
   libMPI_Comm_rank(comm, &rank);
 
-  int len;
-  MPI_Type_size(datatype, &len);
+  int ssize;
+  MPI_Type_size(datatype, &ssize);
+  int data_size = ssize * recvcnts[0];
 
- EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_IREDUCE_SCATTER, (app_ptr)comm, size, rank, (app_ptr)r);
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_IREDUCE_SCATTER, (app_ptr)comm, size, rank, (app_ptr)r, data_size);
+}
+
+static int MPI_Ireduce_scatter_core (CONST void *sendbuf, void *recvbuf, CONST int *recvcnts,
+				     MPI_Datatype datatype, MPI_Op op, MPI_Comm comm,
+				     MPI_Request *r) {
+  return libMPI_Ireduce_scatter (sendbuf, recvbuf, recvcnts, datatype, op, comm, r);
+}
+
+static void MPI_Ireduce_scatter_epilog (CONST void *sendbuf __attribute__((unused)),
+					void *recvbuf __attribute__((unused)),
+					CONST int *recvcnts __attribute__((unused)),
+					MPI_Datatype datatype __attribute__((unused)),
+					MPI_Op op __attribute__((unused)),
+					MPI_Comm comm __attribute__((unused)),
+					MPI_Request *r) {
+ EZTRACE_EVENT_PACKED_1(EZTRACE_MPI_STOP_IREDUCE_SCATTER, (app_ptr)r);
 }
 
 
@@ -56,6 +65,7 @@ int MPI_Ireduce_scatter (CONST void *sendbuf, void *recvbuf, CONST int *recvcnts
   FUNCTION_ENTRY;
 
 
+  MPI_Ireduce_scatter_prolog (sendbuf, recvbuf, recvcnts, datatype, op, comm, r);
   int ret = MPI_Ireduce_scatter_core (sendbuf, recvbuf, recvcnts, datatype, op, comm, r);
   MPI_Ireduce_scatter_epilog (sendbuf, recvbuf, recvcnts, datatype, op, comm, r);
   return ret;
@@ -71,6 +81,7 @@ void mpif_ireduce_scatter_(void *sbuf, void *rbuf, int *rcount,
   MPI_Comm c_comm = MPI_Comm_f2c(*c);
   MPI_Request c_req = MPI_Request_f2c(*r);
 
+  MPI_Ireduce_scatter_prolog(sbuf, rbuf, rcount, c_type, c_op, c_comm, r);
   *error = MPI_Ireduce_scatter_core(sbuf, rbuf, rcount, c_type, c_op, c_comm, &c_req);
   *r = MPI_Request_c2f(c_req);
   MPI_Ireduce_scatter_epilog(sbuf, rbuf, rcount, c_type, c_op, c_comm, r);
