@@ -29,7 +29,7 @@ static void MPI_Iscatterv_prolog(CONST void *sendbuf __attribute__((unused)),
 				 void *recvbuf __attribute__((unused)),
 				 int recvcnt __attribute__((unused)),
 				 MPI_Datatype recvtype __attribute__((unused)),
-				 int root __attribute__((unused)),
+				 int root,
 				 MPI_Comm comm,
 				 MPI_Request *r)
 {
@@ -42,7 +42,7 @@ static void MPI_Iscatterv_prolog(CONST void *sendbuf __attribute__((unused)),
   MPI_Type_size(sendtype, &ssize);
   int data_size = ssize * sendcnts[0];
 
-  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_ISCATTERV, (app_ptr)comm, size, rank, (app_ptr)r, data_size);
+  EZTRACE_EVENT_PACKED_6(EZTRACE_MPI_ISCATTERV, (app_ptr)comm, size, rank, (app_ptr)r, data_size, root);
 }
 
 static int MPI_Iscatterv_core(CONST void *sendbuf,
