@@ -39,7 +39,7 @@ static void MPI_Scatter_prolog(CONST void *sendbuf __attribute__((unused)),
   MPI_Type_size(sendtype, &ssize);
   int data_size = ssize * sendcnt;
 
-  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_Scatter, (app_ptr)comm, size, rank, data_size);
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_START_Scatter, (app_ptr)comm, size, rank, data_size, root);
 }
 
 static int MPI_Scatter_core(CONST void *sendbuf, int sendcnt,
