@@ -40,7 +40,7 @@ static void MPI_Scatterv_prolog(CONST void *sendbuf __attribute__((unused)),
   MPI_Type_size(sendtype, &ssize);
   int data_size = ssize * sendcnts[0];
 
-  EZTRACE_EVENT_PACKED_4(EZTRACE_MPI_START_Scatterv, (app_ptr)comm, size, rank, data_size);
+  EZTRACE_EVENT_PACKED_5(EZTRACE_MPI_START_Scatterv, (app_ptr)comm, size, rank, data_size, root);
 }
 
 static int MPI_Scatterv_core(CONST void *sendbuf,
