@@ -12,15 +12,24 @@
 #include "eztrace_list.h"
 #include "eztrace_stack.h"
 #include "eztrace_convert.h"
-#include "pomp2_lib.h"
+#include "pomp-lib-dummy/pomp2_lib.h"
 
 static struct ezt_list_t section_list;
 
 static int recording_stats = 0;
 static int nb_parallel_region = 0;
 
+/* maximum number of level for nested tasks */
+#define MAX_NESTED_TASKS 128
+
 #define GOMP_CHANGE() if(!recording_stats) CHANGE()
 
+#if 0
+# define OMP_PRINTF printf x
+#else
+# define OMP_PRINTF(...)
+#endif
+
 /* contains all the information of a parallel section */
 struct gomp_section_t {
   void (*func)(void *);
@@ -53,6 +62,24 @@ struct gomp_thread_section_t {
 /* contains the list of parallel sections that a thread is currently processing */
 struct gomp_thread_info_t {
   ezt_stack_t section_stack;
+
+  /* timestamp of the last start_task_create event */
+  double start_create_task[MAX_NESTED_TASKS];
+  int nb_nested_task_creation;
+  /* timestamp of the last start_task_exec event */
+  double start_exec_task[MAX_NESTED_TASKS];
+  int nb_nested_tasks;
+
+  /* total time spent creating tasks */
+  double create_task_duration;
+  /* number of created tasks */
+  unsigned nb_create_task;
+  /* total time spent executing tasks */
+  double exec_task_duration;
+  /* number of executed tasks */
+  unsigned nb_exec_task;
+
+  /* TODO: also count the parallel loops ? */
   struct thread_info_t *p_thread;
 };
 
@@ -61,6 +88,15 @@ struct gomp_process_info_t {
   struct ezt_list_t section_list;
   struct process_info_t *p_process;
   struct ezt_list_t finished_section_list;
+
+  /* total time spent creating tasks */
+  double create_task_duration;
+  /* number of created tasks */
+  unsigned nb_create_task;
+  /* total time spent executing tasks */
+  double exec_task_duration;
+  /* number of executed tasks */
+  unsigned nb_exec_task;
 };
 
 /* add a hook in the process structure in order to store information
@@ -73,6 +109,12 @@ static struct gomp_process_info_t *__register_process_hook(
   g_info->p_process = p_process;
   ezt_list_new(&g_info->section_list);
   ezt_list_new(&g_info->finished_section_list);
+
+  g_info->create_task_duration=0;
+  g_info->nb_create_task=0;
+  g_info->exec_task_duration=0;
+  g_info->nb_exec_task=0;
+
   /* add the hook in the thread info structure */
   ezt_hook_list_add(&g_info->p_process->hooks, g_info,
 		    (uint8_t) EZTRACE_GOMP_EVENTS_ID);
@@ -89,6 +131,20 @@ struct gomp_thread_info_t *__register_thread_hook(int tid) {
   g_info->p_thread = GET_THREAD_INFO(CUR_INDEX, tid);
   ezt_stack_new(&g_info->section_stack);
 
+  int i;
+  for(i=0; i<MAX_NESTED_TASKS; i++) {
+    g_info->start_exec_task[i] = -1;
+    g_info->start_create_task[i] = -1;
+  }
+  g_info->nb_nested_tasks = 0;
+  g_info->nb_nested_task_creation = 0;
+
+  g_info->nb_create_task = 0;
+  g_info->nb_exec_task = 0;
+
+  g_info->create_task_duration = 0;
+  g_info->exec_task_duration = 0;
+
   /* add the hook in the thread info structure */
   ezt_hook_list_add(&g_info->p_thread->hooks, g_info,
 		    (uint8_t) EZTRACE_GOMP_EVENTS_ID);
@@ -126,8 +182,8 @@ struct ezt_list_token_t *__find_matching_section(
   return NULL;
 }
 
-/* OpenMP */
 void handle_gomp_new_fork() {
+
   /* This event occurs when a parallel section begins.
    * This event is generated by the new thread (ie. not by the main thread
    * that called #omp parallel)
@@ -144,14 +200,16 @@ void handle_gomp_new_fork() {
   DECLARE_CUR_THREAD(p_thread);
   INIT_GOMP_THREAD_INFO(p_thread, g_info);
 
-  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
-
-  /* retrieve the gomp_section structure that was created by the main thread */
   POMP2_Region_handle section_id;
   int my_id;
   int nb_threads;
   GET_PARAM_PACKED_3(CUR_EV, section_id, my_id, nb_threads);
 
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+
+  /* retrieve the gomp_section structure that was created by the main thread */
+  OMP_PRINTF("[%x] %s %d (%d threads)\n", CUR_THREAD_ID, __FUNCTION__, section_id, nb_threads);
+
   struct ezt_list_token_t *token = __find_matching_section(p_process,
 							   section_id);
   assert(token);
@@ -247,10 +305,12 @@ void handle_gomp_new_join() {
     struct gomp_thread_section_t *thread_section = (struct gomp_thread_section_t *) token->data;
     struct gomp_section_t *section = thread_section->process_section;
 
+    OMP_PRINTF("[%x] %s %d\n", CUR_THREAD_ID, __FUNCTION__, section->id);
+
     section->join_time[my_id] = CURRENT;
     /* create the links between the main thread and the current thread */
     int res __attribute__ ((__unused__));
-    res = asprintf(&section->link_id_end[my_id], "%d_%d_%d", CUR_RANK,
+    res = asprintf(&section->link_id_end[my_id], "%d_%d_%d_end", CUR_RANK,
 		   section->id, my_id);
     res = asprintf(&section->link_value_end[my_id], "p#%d_section#%d_thread#%d",
 		   CUR_RANK, section->id, my_id);
@@ -304,6 +364,8 @@ void handle_gomp_parallel_start() {
   DECLARE_CUR_PROCESS(p_process);
   INIT_GOMP_PROCESS_INFO(p_process, g_info);
 
+  OMP_PRINTF("[%x] %s %d\n", CUR_THREAD_ID, __FUNCTION__, section->id);
+
   /* add the section structure to the list of pending sections */
   ezt_list_add(&g_info->section_list, &section->token);
 }
@@ -419,6 +481,15 @@ void handle_pomp2_flush_exit() {
 void handle_pomp2_task_create_begin() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+
+  assert(g_info->start_create_task[g_info->nb_nested_task_creation] < 0);
+  assert(g_info->nb_nested_task_creation < MAX_NESTED_TASKS);
+
+  g_info->start_create_task[g_info->nb_nested_task_creation] = CURRENT;
+  g_info->nb_nested_task_creation++;
+
   GOMP_CHANGE()
     pushState(CURRENT, "ST_Thread", thread_id, "GOMP_Task_Create");
 }
@@ -426,20 +497,15 @@ void handle_pomp2_task_create_begin() {
 void handle_pomp2_task_create_end() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
-  GOMP_CHANGE()
-    popState(CURRENT, "ST_Thread", thread_id);
-}
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
 
-void handle_pomp2_task_begin() {
-  FUNC_NAME;
-  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
-  GOMP_CHANGE()
-    pushState(CURRENT, "ST_Thread", thread_id, "GOMP_Task");
-}
+  assert(g_info->start_create_task[g_info->nb_nested_task_creation-1] > 0);
+  g_info->create_task_duration += CURRENT-g_info->start_create_task[g_info->nb_nested_task_creation-1];
+  g_info->start_create_task[g_info->nb_nested_task_creation-1] = -1;
+  g_info->nb_nested_task_creation--;
+  g_info->nb_create_task++;
 
-void handle_pomp2_task_end() {
-  FUNC_NAME;
-  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
   GOMP_CHANGE()
     popState(CURRENT, "ST_Thread", thread_id);
 }
@@ -447,6 +513,15 @@ void handle_pomp2_task_end() {
 void handle_pomp2_untied_task_create_begin() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+
+  assert(g_info->start_create_task[g_info->nb_nested_task_creation] < 0);
+  assert(g_info->nb_nested_task_creation < MAX_NESTED_TASKS);
+
+  g_info->start_create_task[g_info->nb_nested_task_creation] = CURRENT;
+  g_info->nb_nested_task_creation++;
+
   GOMP_CHANGE()
     pushState(CURRENT, "ST_Thread", thread_id, "GOMP_Untied_Task_Create");
 }
@@ -454,6 +529,46 @@ void handle_pomp2_untied_task_create_begin() {
 void handle_pomp2_untied_task_create_end() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+
+  assert(g_info->start_create_task[g_info->nb_nested_task_creation-1] > 0);
+  g_info->create_task_duration += CURRENT-g_info->start_create_task[g_info->nb_nested_task_creation-1];
+  g_info->start_create_task[g_info->nb_nested_task_creation-1] = -1;
+  g_info->nb_nested_task_creation--;
+  g_info->nb_create_task++;
+
+  GOMP_CHANGE()
+    popState(CURRENT, "ST_Thread", thread_id);
+}
+
+
+void handle_pomp2_task_begin() {
+  FUNC_NAME;
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+  assert(g_info->start_exec_task[g_info->nb_nested_tasks] < 0);
+  assert(g_info->nb_nested_tasks<MAX_NESTED_TASKS);
+
+  g_info->start_exec_task[g_info->nb_nested_tasks] = CURRENT;
+  g_info->nb_nested_tasks++;
+
+  GOMP_CHANGE()
+    pushState(CURRENT, "ST_Thread", thread_id, "GOMP_Task");
+}
+
+void handle_pomp2_task_end() {
+  FUNC_NAME;
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+  assert(g_info->start_exec_task[g_info->nb_nested_tasks-1] > 0);
+  g_info->exec_task_duration += CURRENT-g_info->start_exec_task[g_info->nb_nested_tasks-1];
+  g_info->start_exec_task[g_info->nb_nested_tasks-1] = -1;
+  g_info->nb_nested_tasks--;
+  g_info->nb_exec_task++;
+
   GOMP_CHANGE()
     popState(CURRENT, "ST_Thread", thread_id);
 }
@@ -461,6 +576,15 @@ void handle_pomp2_untied_task_create_end() {
 void handle_pomp2_untied_task_begin() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+
+  assert(g_info->start_exec_task[g_info->nb_nested_tasks] < 0);
+  assert(g_info->nb_nested_tasks<MAX_NESTED_TASKS);
+
+  g_info->start_exec_task[g_info->nb_nested_tasks] = CURRENT;
+  g_info->nb_nested_tasks++;
+
   GOMP_CHANGE()
     pushState(CURRENT, "ST_Thread", thread_id, "GOMP_Untied_Task");
 }
@@ -468,6 +592,15 @@ void handle_pomp2_untied_task_begin() {
 void handle_pomp2_untied_task_end() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  DECLARE_CUR_THREAD(p_thread);
+  INIT_GOMP_THREAD_INFO(p_thread, g_info);
+
+  assert(g_info->start_exec_task[g_info->nb_nested_tasks-1] > 0);
+  g_info->exec_task_duration += CURRENT-g_info->start_exec_task[g_info->nb_nested_tasks-1];
+  g_info->start_exec_task[g_info->nb_nested_tasks-1] = -1;
+  g_info->nb_nested_tasks--;
+  g_info->nb_exec_task++;
+
   GOMP_CHANGE()
     popState(CURRENT, "ST_Thread", thread_id);
 }
@@ -493,6 +626,18 @@ void handle_pomp2_for_enter() {
     pushState(CURRENT, "ST_Thread", thread_id, "GOMP_For");
 }
 
+void handle_pomp2_for_enter_extra() {
+  FUNC_NAME;
+  DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
+  wait_for_an_event_in_cur_thread(EZTRACE_CALLING_FUNCTION);
+  GOMP_CHANGE() {
+    char *callsite = malloc(1024*sizeof(char));
+    snprintf(callsite, 1024, "%s", LITL_READ_RAW(CUR_EV)->data);
+    FUNC_NAME;
+    pushStateExtra(CURRENT, "ST_Thread", thread_id, "GOMP_For", callsite);
+  }
+}
+
 void handle_pomp2_for_exit() {
   FUNC_NAME;
   DECLARE_THREAD_ID_STR(thread_id, CUR_INDEX, CUR_THREAD_ID);
@@ -652,7 +797,7 @@ int eztrace_convert_gomp_init() {
     addEntityValue("GOMP_TaskWait", "ST_Thread", "GOMP_TaskWait", GTG_ORANGE);
 
     addEntityValue("GOMP_Task", "ST_Thread", "GOMP_Task", GTG_WHITE);
-    addEntityValue("GOMP_Untied_Task", "ST_Thread", "GOMP_Task", GTG_TEAL);
+    addEntityValue("GOMP_Untied_Task", "ST_Thread", "GOMP_Untied_Task", GTG_TEAL);
     addEntityValue("GOMP_Task_Create", "ST_Thread", "Creating an OpenMP Task",
 		   GTG_KAKI);
     addEntityValue("GOMP_Untied_Task_Create", "ST_Thread",
@@ -731,6 +876,9 @@ int handle_gomp_events(eztrace_event_t *ev) {
   case EZTRACE_POMP2_FOR_ENTER:
     handle_pomp2_for_enter();
     break;
+  case EZTRACE_POMP2_FOR_ENTER_EXTRA:
+    handle_pomp2_for_enter_extra();
+    break;
   case EZTRACE_POMP2_FOR_EXIT:
     handle_pomp2_for_exit();
     break;
@@ -877,6 +1025,38 @@ void print_gomp_stats() {
     if (!p_info)
       continue; /* No gomp process info attached, skip this process */
 
+    /* print the time spent by each thread creating/executing tasks */
+    struct eztrace_container_t *process_cont = GET_PROCESS_CONTAINER(i);
+    unsigned thread_id;
+    for(thread_id = 0; thread_id<process_cont->nb_children; thread_id++) {
+      struct eztrace_container_t *p_thread = process_cont->children[thread_id];
+      struct thread_info_t* thread_info = (struct thread_info_t*) (p_thread->container_info);
+      INIT_GOMP_THREAD_INFO(thread_info, g_info);
+      double thread_duration = p_thread->end_timestamp - p_thread->start_timestamp;
+
+      p_info->create_task_duration += g_info->create_task_duration;
+      p_info->nb_create_task += g_info->nb_create_task;
+      p_info->exec_task_duration += g_info->exec_task_duration;
+      p_info->nb_exec_task += g_info->nb_exec_task;
+
+      printf("%s: (%lf ms)\n", p_thread->name, thread_duration);
+
+      printf("\t%d tasks created (%lf ms, %lf ms per task, %lf%% of the thread run time)\t %d tasks executed (%lf ms, %lf ms per task, %lf%% of the thread run time)\n",
+	     g_info->nb_create_task, g_info->create_task_duration,
+	     (g_info->nb_create_task?(g_info->create_task_duration/g_info->nb_create_task):0),
+	     100*g_info->create_task_duration/thread_duration,
+	     g_info->nb_exec_task, g_info->exec_task_duration,
+	     (g_info->nb_exec_task?(g_info->exec_task_duration/g_info->nb_exec_task):0),
+	     100*g_info->exec_task_duration/thread_duration);
+    }
+
+    /* print the summary for the process */
+    printf("%s: %d tasks created (%lf ms, %lf ms per task)\t %d tasks executed (%lf ms, %lf ms per task)\n",
+	   process_cont->name, p_info->nb_create_task, p_info->create_task_duration,
+	   (p_info->nb_create_task?(p_info->create_task_duration/p_info->nb_create_task):0),
+	   p_info->nb_exec_task, p_info->exec_task_duration,
+	   (p_info->nb_exec_task?(p_info->exec_task_duration/p_info->nb_exec_task):0));
+
     /* todo: implement other statistics (min/max duration, depth, etc.) */
     unsigned nb_sections = 0;
     float total_duration = 0;
@@ -888,7 +1068,7 @@ void print_gomp_stats() {
       total_duration += section->join_done_time - section->start_time;
       nb_sections++;
     }
-    printf("%s: \t %d parallel regions (average duration: %f us)\n",
+    printf("%s: \t %d parallel regions (average duration: %f ms)\n",
 	   p_process->container->name, nb_sections,
 	   total_duration / nb_sections);
   }
