@@ -59,7 +59,12 @@ int check_instructions(void* bin, pid_t child, word_uint sym_addr, word_uint rel
   i.arch = bfd_get_arch(abfd);
   i.mach = bfd_get_mach(abfd);
 
+#if HAVE_BINUTILS_2_28_OR_OLDER
   disassembler_ftype disassemble = disassembler(abfd);
+#else
+  disassembler_ftype disassemble = disassembler(i.arch, bfd_big_endian(abfd), i.mach, abfd);
+#endif
+
   if ( disassemble == NULL ) {
     return 0;
   }
