@@ -12,7 +12,7 @@
  *      Author: Damien Martin-Guillerez <damien.martin-guillerez@inria.fr>
  */
 
-#include <config.h>
+#include <eztrace_config.h>
 #include <binary.h>
 
 #ifdef __x86_64__
