@@ -10,6 +10,8 @@
  *      Author: Damien Martin-Guillerez <damien.martin-guillerez@inria.fr>
  */
 
+#include <eztrace_config.h>
+#if  ENABLE_BINARY_INSTRUMENTATION
 #include <memory.h>
 #include <tracing.h>
 #include <sys/mman.h>
@@ -42,8 +44,9 @@ word_uint allocate_buffer(pid_t child, size_t size) {
   return r;
 }
 
-void correct_buffer_allocation(pid_t child, size_t required_size,
-                               size_t actual_size) {
+void correct_buffer_allocation(pid_t child __attribute__((unused)), size_t required_size,
+			       size_t actual_size) {
   currentPointer -= (required_size - actual_size);
 }
 
+#endif
