@@ -14,7 +14,7 @@
  *      Author: Damien Martin-Guillerez <damien.martin-guillerez@inria.fr>
  */
 
-#include <config.h>
+#include <eztrace_config.h>
 #include <opcodes.h>
 
 #if __x86_64__
